# Esbonio [![PyPI](https://img.shields.io/pypi/v/esbonio?style=flat-square)](https://pypi.org/project/esbonio) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/esbonio?style=flat-square)](https://pypi.org/project/esbonio)

Esbonio - to explain.

**This package is in early development**

A Python package that provides a number of Sphinx extensions and a [Language Server](https://microsoft.github.io/language-server-protocol/) that
aims to make it easier to work with Sphinx documentation projects in editors that support it.
## Installation

If you are just afer the Sphinx extensions, then you can install `esbonio` with the following

```
$ pip install esbonio
```

However if you are looking to use the language server then some additional dependencies are
required, which can be installed as follows

```
$ pip install esbonio[lsp]
```
